==> spip_4.1.5+dfsg.orig.tar.xz: ecrire/lang/public_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=ro
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Prima pagină', # MODIF
	'article' => 'Articol',
	'articles' => 'Articole',
	'articles_auteur' => 'Articole de acelaşi autor',
	'articles_populaires' => 'Cele mai populare articole',
	'articles_rubrique' => 'Articolele acestei rubrici',
	'aucun_article' => 'Nu există nici un articol la această adresă',
	'aucun_auteur' => 'Nu există nici un autor la această adresă',
	'aucun_site' => 'Nu există nici un site la această adresă',
	'aucune_breve' => 'Nu există nici o ştire la această adresă',
	'aucune_rubrique' => 'Nu există nici o rubrică la această adresă',
	'auteur' => 'Autor',
	'autres' => 'Altele',
	'autres_breves' => 'Alte ştiri',
	'autres_groupes_mots_clefs' => 'Alte grupuri de cuvinte-cheie',
	'autres_sites' => 'Alte site-uri',

	// B
	'bonjour' => 'Bună ziua',

	// C
	'commenter_site' => 'Comentaţi acest site',
	'copie_document_impossible' => 'Imposibil de copiat documentul',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Ultima adăugare',
	'dernieres_breves' => 'Ultimele ştiri',
	'derniers_articles' => 'Ultimele articole',
	'derniers_commentaires' => 'Ultimele comentarii',
	'derniers_messages_forum' => 'Ultimele mesaje publicate în forum-uri',

	// E
	'edition_mode_texte' => 'Editare în mod text a',
	'en_reponse' => 'Răspuns la :',
	'en_resume' => 'Pe scurt',
	'envoyer_message' => 'Trimiteţi un mesaj',
	'espace_prive' => 'Secţiunea protejată',

	// F
	'formats_acceptes' => 'Formate acceptate : @formats@.',

	// H
	'hierarchie_site' => 'Ierarhia site-ului',

	// J
	'jours' => 'zile',

	// L
	'lien_connecter' => 'Conectare',

	// M
	'meme_auteur' => 'De acelaşi autor',
	'meme_rubrique' => 'În aceaşi rubrică',
	'memes_auteurs' => 'De aceaşi autori',
	'message' => 'Mesaj',
	'messages_forum' => 'Mesajele forum-ului', # MODIF
	'messages_recents' => 'Cele mai recente mesaje de forum',
	'mots_clef' => 'Cuvânt-cheie',
	'mots_clefs' => 'Cuvinte-cheie',
	'mots_clefs_meme_groupe' => 'Cuvinte-cheie în acelaşi grup',

	// N
	'navigation' => 'Navigare',
	'nom' => 'Nume',
	'nouveautes' => 'Noutăţi',
	'nouveautes_web' => 'Noutăţi pe Web',
	'nouveaux_articles' => 'Articole noi',
	'nouvelles_breves' => 'Ştiri noi',

	// P
	'page_precedente' => 'pagina anterioară',
	'page_suivante' => 'pagina următoare',
	'par_auteur' => 'de ',
	'participer_site' => 'Puteţi deveni o parte activă a acestui site şi puteţi să vă scrieţi propriile articole înregistrându-vă cu ajutorul formularului de mai jos. Veţi primi în scurt timp un email conţinând un cod de acces la secţiunea protejată a acestui site.',
	'plan_site' => 'Harta site-ului',
	'popularite' => 'Popularitate',
	'poster_message' => 'Trimiteţi un mesaj',
	'proposer_site' => 'Puteţi propune un site de adăugat în această rubrică :',

	// R
	'repondre_article' => 'Răspundeţi la acest articol',
	'repondre_breve' => 'Răspundeţi la acestă ştire',
	'resultats_recherche' => 'Rezultatele căutarii',
	'retour_debut_forums' => 'Înapoi la începutul forum-urilor',
	'rubrique' => 'Rubrică',
	'rubriques' => 'Rubrici',

	// S
	'signatures_petition' => 'Semnături',
	'site_realise_avec_spip' => 'Site realizat cu SPIP',
	'sites_web' => 'Site-uri Web',
	'sous_rubriques' => 'Sub-rubrici',
	'spam' => 'Spam',
	'suite' => 'continuă',
	'sur_web' => 'Pe Web',
	'syndiquer_rubrique' => 'Sindicalizaţi această rubrică',
	'syndiquer_site' => 'Sindicalizaţi întregul site',

	// T
	'texte_lettre_information' => 'Iată scrisoarea de informaţii a site-ului',
	'texte_lettre_information_2' => 'Această scrisoare conţine lista noutatilor publicate de la',

	// V
	'ver_imprimer' => 'Versiunea imprimabilă',
	'voir_en_ligne' => 'Vedeţi în direct',
	'voir_squelette' => 'vedeţi scheletul acestei pagini'
);

==> spip_4.4.7+dfsg.orig.tar.xz: ecrire/lang/public_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=ro
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Prima pagină', # MODIF
	'article' => 'Articol',
	'articles' => 'Articole',
	'articles_auteur' => 'Articole de acelaşi autor',
	'articles_populaires' => 'Cele mai populare articole',
	'articles_rubrique' => 'Articolele acestei rubrici',
	'aucun_article' => 'Nu există nici un articol la această adresă',
	'aucun_auteur' => 'Nu există nici un autor la această adresă',
	'aucun_site' => 'Nu există nici un site la această adresă',
	'aucune_breve' => 'Nu există nici o ştire la această adresă',
	'aucune_rubrique' => 'Nu există nici o rubrică la această adresă',
	'auteur' => 'Autor',
	'autres' => 'Altele',
	'autres_breves' => 'Alte ştiri',
	'autres_groupes_mots_clefs' => 'Alte grupuri de cuvinte-cheie',
	'autres_sites' => 'Alte site-uri',

	// B
	'bonjour' => 'Bună ziua',

	// C
	'commenter_site' => 'Comentaţi acest site',
	'copie_document_impossible' => 'Imposibil de copiat documentul',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Ultima adăugare',
	'dernieres_breves' => 'Ultimele ştiri',
	'derniers_articles' => 'Ultimele articole',
	'derniers_commentaires' => 'Ultimele comentarii',
	'derniers_messages_forum' => 'Ultimele mesaje publicate în forum-uri',

	// E
	'edition_mode_texte' => 'Editare în mod text a',
	'en_reponse' => 'Răspuns la :',
	'en_resume' => 'Pe scurt',
	'envoyer_message' => 'Trimiteţi un mesaj',
	'espace_prive' => 'Secţiunea protejată',

	// F
	'formats_acceptes' => 'Formate acceptate : @formats@.',

	// H
	'hierarchie_site' => 'Ierarhia site-ului',

	// J
	'jours' => 'zile',

	// L
	'lien_connecter' => 'Conectare',

	// M
	'meme_auteur' => 'De acelaşi autor',
	'meme_rubrique' => 'În aceaşi rubrică',
	'memes_auteurs' => 'De aceaşi autori',
	'message' => 'Mesaj',
	'messages_forum' => 'Mesajele forum-ului', # MODIF
	'messages_recents' => 'Cele mai recente mesaje de forum',
	'mots_clef' => 'Cuvânt-cheie',
	'mots_clefs' => 'Cuvinte-cheie',
	'mots_clefs_meme_groupe' => 'Cuvinte-cheie în acelaşi grup',

	// N
	'navigation' => 'Navigare',
	'nom' => 'Nume',
	'nouveautes' => 'Noutăţi',
	'nouveautes_web' => 'Noutăţi pe Web',
	'nouveaux_articles' => 'Articole noi',
	'nouvelles_breves' => 'Ştiri noi',

	// P
	'page_precedente' => 'pagina anterioară',
	'page_suivante' => 'pagina următoare',
	'par_auteur' => 'de ',
	'participer_site' => 'Puteţi deveni o parte activă a acestui site şi puteţi să vă scrieţi propriile articole înregistrându-vă cu ajutorul formularului de mai jos. Veţi primi în scurt timp un email conţinând un cod de acces la secţiunea protejată a acestui site.',
	'plan_site' => 'Harta site-ului',
	'popularite' => 'Popularitate',
	'poster_message' => 'Trimiteţi un mesaj',
	'proposer_site' => 'Puteţi propune un site de adăugat în această rubrică :',

	// R
	'repondre_article' => 'Răspundeţi la acest articol',
	'repondre_breve' => 'Răspundeţi la acestă ştire',
	'resultats_recherche' => 'Rezultatele căutarii',
	'retour_debut_forums' => 'Înapoi la începutul forum-urilor',
	'rubrique' => 'Rubrică',
	'rubriques' => 'Rubrici',

	// S
	'signatures_petition' => 'Semnături',
	'site_realise_avec_spip' => 'Site realizat cu SPIP',
	'sites_web' => 'Site-uri Web',
	'sous_rubriques' => 'Sub-rubrici',
	'spam' => 'Spam',
	'suite' => 'continuă',
	'sur_web' => 'Pe Web',
	'syndiquer_rubrique' => 'Sindicalizaţi această rubrică',
	'syndiquer_site' => 'Sindicalizaţi întregul site',

	// T
	'texte_lettre_information' => 'Iată scrisoarea de informaţii a site-ului',
	'texte_lettre_information_2' => 'Această scrisoare conţine lista noutatilor publicate de la',

	// V
	'ver_imprimer' => 'Versiunea imprimabilă',
	'voir_en_ligne' => 'Vedeţi în direct',
	'voir_squelette' => 'vedeţi scheletul acestei pagini',
];
